@@ -13,11 +13,10 @@
 
 
 import os
-import pkg_resources
 from argparse import ArgumentParser, HelpFormatter
 from mktxp.cli.config.config import config_handler, MKTXPConfigKeys, CustomConfig
 from mktxp.utils.utils import FSHelper, UniquePartialMatchList, run_cmd
-
+from importlib.metadata import version as Version
 
 class MKTXPCommands:
     INFO = 'info'
@@ -41,7 +40,7 @@ class MKTXPOptionsParser:
     '''
     def __init__(self):
         self._script_name = f'MKTXP'
-        version = pkg_resources.require("mktxp")[0].version
+        version = Version('mktxp')
         self._description =  \
 f'''
 Prometheus Exporter for Mikrotik RouterOS, version {version}
@@ -215,7 +214,7 @@ Selected metrics info can be printed on the command line. For more information,
     def _add_entry_name(parser, registered_only = False, required = True, help = 'MKTXP Entry name'):
         parser.add_argument('-en', '--entry-name', dest = 'entry_name',
             type = str,
-            metavar = config_handler.registered_entries() if registered_only else None,
+            metavar = list(config_handler.registered_entries()) if registered_only else None,
             required = required,
             choices = UniquePartialMatchList(config_handler.registered_entries())if registered_only else None,
             help = help)
@@ -232,11 +231,10 @@ Selected metrics info can be printed on the command line. For more information,
             return editor
 
         commands = ['which nano', 'which vi', 'which vim']
-        quiet = not config_handler.system_entry().verbose_mode
         for command in commands:
-            editor = run_cmd(command, quiet = quiet).rstrip()
+            editor = run_cmd(command, quiet = True).rstrip()
             if editor:
-                break                                  
+                break               
         return editor
 
 
