@@ -15,6 +15,7 @@
 from mktxp.collector.base_collector import BaseCollector
 from mktxp.flow.processor.output import BaseOutputProcessor
 from mktxp.datasource.system_resource_ds import SystemResourceMetricsDataSource
+from mktxp.utils.utils import check_for_updates
 
 
 class SystemResourceCollector(BaseCollector):
@@ -26,17 +27,10 @@ class SystemResourceCollector(BaseCollector):
                            'cpu', 'cpu_count', 'cpu_frequency', 'cpu_load', 
                            'free_hdd_space', 'total_hdd_space', 
                            'architecture_name', 'board_name']
-                                   
-        resource_records = SystemResourceMetricsDataSource.metric_records(router_entry, metric_labels = resource_labels)   
-        if resource_records:
-            # translate records to appropriate values
-            translated_fields = ['uptime']        
-            for resource_record in resource_records:
-                for translated_field in translated_fields:
-                    value = resource_record.get(translated_field, None)    
-                    if value:            
-                        resource_record[translated_field] = SystemResourceCollector._translated_values(translated_field, value)
+        translation_table = {'uptime': lambda value: BaseOutputProcessor.parse_timedelta_seconds(value)}
 
+        resource_records = SystemResourceMetricsDataSource.metric_records(router_entry, metric_labels = resource_labels, translation_table=translation_table)   
+        if resource_records:
             uptime_metrics = BaseCollector.gauge_collector('system_uptime', 'Time interval since boot-up', resource_records, 'uptime', ['version', 'board_name', 'cpu', 'architecture_name'])
             yield uptime_metrics
 
@@ -61,11 +55,12 @@ class SystemResourceCollector(BaseCollector):
             cpu_frequency_metrics = BaseCollector.gauge_collector('system_cpu_frequency', 'Current CPU frequency', resource_records, 'cpu_frequency', ['version', 'board_name', 'cpu', 'architecture_name'])
             yield cpu_frequency_metrics
 
+            # Check for updates
+            if router_entry.config_entry.check_for_updates:
+                for record in resource_records:
+                    cur_version, newest_version = check_for_updates(record['version'])
+                    record['newest_version'] = str(newest_version)
+                    record['update_available'] = cur_version < newest_version
 
-    # Helpers
-    @staticmethod
-    def _translated_values(translated_field, value):
-        return {
-                'uptime': lambda value: BaseOutputProcessor.parse_timedelta_seconds(value)
-                }[translated_field](value)
-
+                update_available_metrics = BaseCollector.gauge_collector('system_update_available', 'Is there a newer version available', resource_records, 'update_available', ['newest_version',])
+                yield update_available_metrics
