@@ -11,16 +11,16 @@
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
 
-
 from mktxp.datasource.base_ds import BaseDSProcessor
 from mktxp.datasource.package_ds import PackageMetricsDataSource
-
+from mktxp.flow.router_entry import RouterEntryWirelessType
 
 class WirelessMetricsDataSource:
     ''' Wireless Metrics data provider
     '''             
-    WIFIWAVE2 = 'wifiwave2'
     WIRELESS = 'wireless'
+    WIFIWAVE2 = 'wifiwave2'
+    WIFI = 'wifi'
 
     @staticmethod
     def metric_records(router_entry, *, metric_labels = None, add_router_id = True):
@@ -38,17 +38,16 @@ class WirelessMetricsDataSource:
 
             return BaseDSProcessor.trimmed_records(router_entry, router_records = registration_table_records, metric_labels = metric_labels, add_router_id = add_router_id,)
         except Exception as exc:
-            print(f'Error getting wireless registration table info from router{router_entry.router_name}@{router_entry.config_entry.hostname}: {exc}')
+            print(f'Error getting wireless registration table info from router {router_entry.router_name}@{router_entry.config_entry.hostname}: {exc}')
             return None
 
-
     @staticmethod
     def wireless_package(router_entry):
-        if not router_entry.wifi_package:
-            ww2_installed = PackageMetricsDataSource.is_package_installed(router_entry, package_name = WirelessMetricsDataSource.WIFIWAVE2)
-            router_entry.wifi_package = WirelessMetricsDataSource.WIFIWAVE2 if ww2_installed else WirelessMetricsDataSource.WIRELESS
-        return router_entry.wifi_package
+        if router_entry.wireless_type in (RouterEntryWirelessType.DUAL, RouterEntryWirelessType.WIRELESS):
+            return WirelessMetricsDataSource.WIRELESS
+        elif router_entry.wireless_type == RouterEntryWirelessType.WIFIWAVE2:
+            return WirelessMetricsDataSource.WIFIWAVE2
+        else:
+            return WirelessMetricsDataSource.WIFI
+
 
-    @staticmethod
-    def wifiwave2_installed(router_entry):
-        return WirelessMetricsDataSource.wireless_package(router_entry) == WirelessMetricsDataSource.WIFIWAVE2
