@@ -20,8 +20,9 @@ from mktxp.collector.connection_collector import IPConnectionCollector
 from mktxp.collector.interface_collector import InterfaceCollector
 from mktxp.collector.health_collector import HealthCollector
 from mktxp.collector.identity_collector import IdentityCollector
+from mktxp.collector.ipsec_collector import IPSecCollector
 from mktxp.collector.public_ip_collector import PublicIPAddressCollector
-from mktxp.collector.ipv6_neighbor_collector import IPv6NeighborCollector
+from mktxp.collector.neighbor_collector import NeighborCollector
 from mktxp.collector.monitor_collector import MonitorCollector
 from mktxp.collector.poe_collector import POECollector
 from mktxp.collector.netwatch_collector import NetwatchCollector
@@ -36,6 +37,17 @@ from mktxp.collector.mktxp_collector import MKTXPCollector
 from mktxp.collector.user_collector import UserCollector
 from mktxp.collector.queue_collector import QueueTreeCollector
 from mktxp.collector.queue_collector import QueueSimpleCollector
+from mktxp.collector.kid_control_device_collector import KidDeviceCollector
+from mktxp.collector.bfd_collector import BFDCollector
+from mktxp.collector.bgp_collector import BGPCollector
+from mktxp.collector.routing_stats_collector import RoutingStatsCollector
+from mktxp.collector.eoip_collector import EOIPCollector
+from mktxp.collector.gre_collector import GRECollector
+from mktxp.collector.ipip_collector import IPIPCollector
+from mktxp.collector.lte_collector import LTECollector
+from mktxp.collector.switch_collector import SwitchPortCollector
+from mktxp.collector.certificate_collector import CertificateCollector
+from mktxp.collector.dns_collector import DNSCollector
 
 class CollectorRegistry:
     ''' MKTXP Collectors Registry
@@ -51,11 +63,13 @@ class CollectorRegistry:
         self.register(CollectorKeys.HEALTH_COLLECTOR, HealthCollector.collect)
         self.register(CollectorKeys.PUBLIC_IP_ADDRESS_COLLECTOR, PublicIPAddressCollector.collect)
 
-        self.register(CollectorKeys.IPV6_NEIGHBOR_COLLECTOR, IPv6NeighborCollector.collect)
+        self.register(CollectorKeys.NEIGHBOR_COLLECTOR, NeighborCollector.collect)
+        self.register(CollectorKeys.DNS_COLLECTOR, DNSCollector.collect)
 
         self.register(CollectorKeys.PACKAGE_COLLECTOR, PackageCollector.collect)
         self.register(CollectorKeys.DHCP_COLLECTOR, DHCPCollector.collect)
         self.register(CollectorKeys.IP_CONNECTION_COLLECTOR, IPConnectionCollector.collect)
+        self.register(CollectorKeys.IPSEC_COLLECTOR, IPSecCollector.collect)
         self.register(CollectorKeys.POOL_COLLECTOR, PoolCollector.collect)
         self.register(CollectorKeys.INTERFACE_COLLECTOR, InterfaceCollector.collect)
 
@@ -72,7 +86,20 @@ class CollectorRegistry:
         self.register(CollectorKeys.QUEUE_TREE_COLLECTOR, QueueTreeCollector.collect)
         self.register(CollectorKeys.QUEUE_SIMPLE_COLLECTOR, QueueSimpleCollector.collect)
 
+        self.register(CollectorKeys.KID_CONTROL_DEVICE_COLLECTOR, KidDeviceCollector.collect)
+        self.register(CollectorKeys.BFD_COLLECTOR, BFDCollector.collect)
+        self.register(CollectorKeys.BGP_COLLECTOR, BGPCollector.collect)
+        self.register(CollectorKeys.EOIP_COLLECTOR, EOIPCollector.collect)
+        self.register(CollectorKeys.GRE_COLLECTOR, GRECollector.collect)
+        self.register(CollectorKeys.IPIP_COLLECTOR, IPIPCollector.collect)
+        self.register(CollectorKeys.LTE_COLLECTOR, LTECollector.collect)
+        self.register(CollectorKeys.SWITCH_PORT_COLLECTOR, SwitchPortCollector.collect)
+
+        self.register(CollectorKeys.ROUTING_STATS_COLLECTOR, RoutingStatsCollector.collect)
+        self.register(CollectorKeys.CERTIFICATE_COLLECTOR, CertificateCollector.collect)
+
         self.register(CollectorKeys.MKTXP_COLLECTOR, MKTXPCollector.collect)
+        
 
     def register(self, collector_ID, collect_func):
         self.registered_collectors[collector_ID] = collect_func
