@@ -17,6 +17,7 @@ import socket
 import collections
 from datetime import datetime
 from mktxp.cli.config.config import config_handler
+import functools 
 
 # Fix UTF-8 decode error
 # See: https://github.com/akpw/mktxp/issues/47
@@ -31,10 +32,17 @@ routeros_api.api_structure.default_structure = collections.defaultdict(routeros_
 
 from routeros_api import RouterOsApiPool
 
-
 class RouterAPIConnectionError(Exception):
     pass
 
+def check_connected(func):
+    @functools.wraps(func)
+    def wrapper(self, *args, **kwargs):
+        if not self.is_connected():
+            raise RouterAPIConnectionError(f'No network connection to router: {self.router_name}@{self.config_entry.hostname}')
+        else:
+            return func(self, *args, **kwargs)
+    return wrapper
 
 class RouterAPIConnection:
     ''' Base wrapper interface for the routeros_api library
@@ -59,18 +67,13 @@ class RouterAPIConnection:
                 ssl_verify = self.config_entry.ssl_certificate_verify,
                 ssl_context = ctx)
         
-        self.connection.socket_timeout = config_handler.system_entry().socket_timeout
+        self.connection.socket_timeout = config_handler.system_entry.socket_timeout
         self.api = None
-
+    
     def is_connected(self):
-        if not (self.connection and self.connection.connected and self.api):
-            return False
-        try:
-            self.api.get_resource('/system/identity').get()
+        if self.connection and self.connection.connected and self.api:
             return True
-        except (socket.error, socket.timeout, Exception) as exc:
-            self._set_connect_state(success = False, exc = exc)
-            return False
+        return False
 
     def connect(self):
         connect_time = datetime.now()
@@ -78,25 +81,25 @@ class RouterAPIConnection:
             return
         try:
             print(f'Connecting to router {self.router_name}@{self.config_entry.hostname}')
+            self.connection.plaintext_login = self.config_entry.plaintext_login
             self.api = self.connection.get_api()
             self._set_connect_state(success = True, connect_time = connect_time)
         except (socket.error, socket.timeout, Exception) as exc:
             self._set_connect_state(success = False, connect_time = connect_time, exc = exc)
-            #raise RouterAPIConnectionError
+            raise RouterAPIConnectionError(f'Failed attemp to establish network connection to router: {self.router_name}@{self.config_entry.hostname}')
 
+    @check_connected
     def router_api(self):
-        if not self.is_connected():
-            self.connect()
         return self.api
 
     def _in_connect_timeout(self, connect_timestamp):
         connect_delay = self._connect_delay()
         if (connect_timestamp - self.last_failure_timestamp) < connect_delay:
-            if config_handler.system_entry().verbose_mode: 
+            if config_handler.system_entry.verbose_mode: 
                 print(f'{self.router_name}@{self.config_entry.hostname}: in connect timeout, {int(connect_delay - (connect_timestamp - self.last_failure_timestamp))}secs remaining')
                 print(f'Successive failure count: {self.successive_failure_count}')
             return True
-        if config_handler.system_entry().verbose_mode: 
+        if config_handler.system_entry.verbose_mode: 
             print(f'{self.router_name}@{self.config_entry.hostname}: OK to connect')
             if self.last_failure_timestamp > 0:
                 print(f'Seconds since last failure: {connect_timestamp - self.last_failure_timestamp}')
@@ -104,7 +107,7 @@ class RouterAPIConnection:
         return False
 
     def _connect_delay(self):
-        mktxp_entry = config_handler.system_entry()
+        mktxp_entry = config_handler.system_entry
         connect_delay = (1 + self.successive_failure_count / mktxp_entry.delay_inc_div) * mktxp_entry.initial_delay_on_failure
         return connect_delay if connect_delay < mktxp_entry.max_delay_on_failure else mktxp_entry.max_delay_on_failure
 
@@ -119,12 +122,3 @@ class RouterAPIConnection:
             self.successive_failure_count += 1
             self.last_failure_timestamp = connect_time.timestamp() 
             print(f'{connect_time.strftime("%Y-%m-%d %H:%M:%S")} Connection to router {self.router_name}@{self.config_entry.hostname} has failed: {exc}')
-
-
-
-
-
-
-
-
-
